@@ -1,66 +1,50 @@
-use crate::manifest::descriptions_list::DescriptionsListTracer;
+use crate::auto_path::AutoPath;
+use crate::manifest::description::{PackFlow, PackFlowDescription};
+use crate::manifest::paths::PathsTracer;
 use derive_more::{Deref, DerefMut};
 use once_cell::sync::Lazy;
 use rill_engine::tracers::tracer::Tracer;
-use rill_protocol::flow::core::Flow;
-use rill_protocol::io::provider::Description;
-use std::ops::Deref;
+use rill_protocol::flow::core::FlowMode;
 use std::sync::Arc;
 
-static DESCRIPTIONS: Lazy<DescriptionsListTracer> = Lazy::new(DescriptionsListTracer::new);
+static PATHS: Lazy<PathsTracer> = Lazy::new(PathsTracer::new);
 
-// TODO: Remove and replace with `Binder`! It unregistered wrong!
 /// `Binded` wraps a tracer to automatically track it in the global `DescriptionFlow`.
 #[derive(Deref, DerefMut, Debug, Clone)]
-pub struct Binded<T> {
+pub struct BindedTracer<T: PackFlow> {
     #[deref]
     #[deref_mut]
-    tracer: T,
-    description: Description,
+    tracer: Tracer<T>,
+    binder: Binder,
 }
 
-impl<T> Binded<T> {
-    pub fn new<F>(tracer: T) -> Self
+impl<T: PackFlow> BindedTracer<T> {
+    pub fn new<S>(auto_path: AutoPath, mode: FlowMode, spec: S) -> Self
     where
-        F: Flow,
-        T: Deref<Target = Tracer<F>>,
+        S: Into<T>,
     {
-        let description = tracer.description().clone();
-        let this = Self {
-            tracer,
-            description,
-        };
-        this.register();
-        this
-    }
-
-    fn register(&self) {
-        let path = self.description.path.clone();
-        DESCRIPTIONS.add_record(path, self.description.clone());
-    }
-
-    fn unregister(&self) {
-        let path = self.description.path.clone();
-        DESCRIPTIONS.remove_record(path);
-    }
-}
-
-impl<T> Drop for Binded<T> {
-    fn drop(&mut self) {
-        self.unregister();
+        let state = spec.into();
+        let tracer = Tracer::new(state, auto_path.into(), mode);
+        let binder = Binder::new(&tracer);
+        Self { tracer, binder }
     }
 }
 
 /// `Binder` wraps a tracer to automatically track it in the global `DescriptionFlow`.
 #[derive(Deref, DerefMut, Debug, Clone)]
-pub struct Binder {
+struct Binder {
     /// Wrapped with `Arc` to have a single instance of inner only.
     inner: Arc<BinderInner>,
 }
 
 impl Binder {
-    pub fn new<T: Flow>(tracer: &Tracer<T>) -> Self {
-        let description = tracer.description().clone();
+    pub fn new<T: PackFlow>(tracer: &Tracer<T>) -> Self {
+        let desc = tracer.description();
+        let description = PackFlowDescription {
+            path: desc.path.clone(),
+            layer: T::layer(),
+            stream_type: desc.stream_type.clone(),
+        };
         let inner = BinderInner { description };
         let this = Self {
             inner: Arc::new(inner),
@@ -71,21 +55,21 @@ impl Binder {
 }
 
 #[derive(Deref, DerefMut, Debug, Clone)]
-pub struct BinderInner {
-    description: Description,
+struct BinderInner {
+    description: PackFlowDescription,
 }
 
 impl BinderInner {
     fn register(&self) {
         let path = self.description.path.clone();
         //log::debug!("REGISTERING: {}", path);
-        DESCRIPTIONS.add_record(path, self.description.clone());
+        PATHS.add_path(path, self.description.clone());
     }
 
     fn unregister(&self) {
         let path = self.description.path.clone();
         //log::debug!("UNREGISTERING: {}", path);
-        DESCRIPTIONS.remove_record(path);
+        PATHS.remove_path(path);
     }
 }
 
